/***************************************************************************
 *   Copyright (C) 2013 by kf <freitag@kde.org>                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/

#include "kta.h"
#include <kdebug.h>

#include "akonadi/contact/contactsearchjob.h"
#include "akonadi/session.h"
#include "akonadi/control.h"

kta::kta()
    : KMainWindow()
{
    // tell the KXmlGuiWindow that this is indeed the main widget
    QWidget* w = new QWidget(this);
    setCentralWidget(w);
    m_ui.setupUi(w);
    doAkonadi();
}

void kta::doAkonadi()
{
  // Initialize Akonadi usage
  if ( !Akonadi::Control::start( this ) ) {
    kError() << "Failed to start Akonadi!";
  }
  Akonadi::Control::widgetNeedsAkonadi( this );

  // --------------------------------------------------------
  // FIXME: Use a Uid of a contact in your address book here:
  const QString uid("DmCW4B3O5d");
  // --------------------------------------------------------

  Akonadi::ContactSearchJob *job = new Akonadi::ContactSearchJob( this );

  job->setLimit( 1 );
  job->setQuery( Akonadi::ContactSearchJob::ContactUid , uid );
  job->setProperty( "SearchCrit", uid );
  connect( job, SIGNAL( result( KJob* ) ), this, SLOT( searchResult( KJob* ) ) );

}

void kta::searchResult( KJob* job )
{
  Akonadi::ContactSearchJob *searchJob = qobject_cast<Akonadi::ContactSearchJob*>( job );

  if( searchJob->error() ) {
    kDebug() << "Address search job failed: " << job->errorString();
  }

  const KABC::Addressee::List contacts = searchJob->contacts();
  kDebug() << "Found list of " << contacts.size() << " addresses as search result";
  QString l = QString("Akonadi search result %1, search UID <i>%2</i>").arg(contacts.size())
      .arg(job->property("SearchCrit").toString());
  m_ui.label->setText( l );

}

kta::~kta()
{
}

#include "kta.moc"
